/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM nsIMsgSearchTerm.idl
 */

#ifndef __gen_nsIMsgSearchTerm_h__
#define __gen_nsIMsgSearchTerm_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

#ifndef __gen_nsMsgSearchCore_h__
#include "nsMsgSearchCore.h"
#endif

#ifndef __gen_nsIMsgSearchValue_h__
#include "nsIMsgSearchValue.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIMsgDBHdr; /* forward declaration */

class nsIMsgDatabase; /* forward declaration */

class nsIMsgSearchScopeTerm; /* forward declaration */


/* starting interface:    nsIMsgSearchTerm */
#define NS_IMSGSEARCHTERM_IID_STR "bb0e5261-c7da-44de-83b9-a39064ad707f"

#define NS_IMSGSEARCHTERM_IID \
  {0xbb0e5261, 0xc7da, 0x44de, \
    { 0x83, 0xb9, 0xa3, 0x90, 0x64, 0xad, 0x70, 0x7f }}

class NS_NO_VTABLE NS_SCRIPTABLE nsIMsgSearchTerm : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_IMSGSEARCHTERM_IID)

  /* attribute nsMsgSearchAttribValue attrib; */
  NS_SCRIPTABLE NS_IMETHOD GetAttrib(nsMsgSearchAttribValue *aAttrib) = 0;
  NS_SCRIPTABLE NS_IMETHOD SetAttrib(nsMsgSearchAttribValue aAttrib) = 0;

  /* attribute nsMsgSearchOpValue op; */
  NS_SCRIPTABLE NS_IMETHOD GetOp(nsMsgSearchOpValue *aOp) = 0;
  NS_SCRIPTABLE NS_IMETHOD SetOp(nsMsgSearchOpValue aOp) = 0;

  /* attribute nsIMsgSearchValue value; */
  NS_SCRIPTABLE NS_IMETHOD GetValue(nsIMsgSearchValue **aValue) = 0;
  NS_SCRIPTABLE NS_IMETHOD SetValue(nsIMsgSearchValue *aValue) = 0;

  /* attribute boolean booleanAnd; */
  NS_SCRIPTABLE NS_IMETHOD GetBooleanAnd(PRBool *aBooleanAnd) = 0;
  NS_SCRIPTABLE NS_IMETHOD SetBooleanAnd(PRBool aBooleanAnd) = 0;

  /* attribute ACString arbitraryHeader; */
  NS_SCRIPTABLE NS_IMETHOD GetArbitraryHeader(nsACString & aArbitraryHeader) = 0;
  NS_SCRIPTABLE NS_IMETHOD SetArbitraryHeader(const nsACString & aArbitraryHeader) = 0;

  /**
     * Not to be confused with arbitraryHeader, which is a header in the
     * rfc822 message. This is a property of the nsIMsgDBHdr, and may have
     * nothing to do the message headers, e.g., gloda-id.
     * value.str will be compared with nsIMsgHdr::GetProperty(hdrProperty).
     */
  /* attribute ACString hdrProperty; */
  NS_SCRIPTABLE NS_IMETHOD GetHdrProperty(nsACString & aHdrProperty) = 0;
  NS_SCRIPTABLE NS_IMETHOD SetHdrProperty(const nsACString & aHdrProperty) = 0;

  /* attribute ACString customId; */
  NS_SCRIPTABLE NS_IMETHOD GetCustomId(nsACString & aCustomId) = 0;
  NS_SCRIPTABLE NS_IMETHOD SetCustomId(const nsACString & aCustomId) = 0;

  /* attribute boolean beginsGrouping; */
  NS_SCRIPTABLE NS_IMETHOD GetBeginsGrouping(PRBool *aBeginsGrouping) = 0;
  NS_SCRIPTABLE NS_IMETHOD SetBeginsGrouping(PRBool aBeginsGrouping) = 0;

  /* attribute boolean endsGrouping; */
  NS_SCRIPTABLE NS_IMETHOD GetEndsGrouping(PRBool *aEndsGrouping) = 0;
  NS_SCRIPTABLE NS_IMETHOD SetEndsGrouping(PRBool aEndsGrouping) = 0;

  /* boolean matchRfc822String (in string aString, in string charset, in boolean charsetOverride); */
  NS_SCRIPTABLE NS_IMETHOD MatchRfc822String(const char *aString, const char *charset, PRBool charsetOverride, PRBool *_retval NS_OUTPARAM) = 0;

  /* boolean matchRfc2047String (in string aString, in string charset, in boolean charsetOverride); */
  NS_SCRIPTABLE NS_IMETHOD MatchRfc2047String(const char *aString, const char *charset, PRBool charsetOverride, PRBool *_retval NS_OUTPARAM) = 0;

  /* boolean matchDate (in PRTime aTime); */
  NS_SCRIPTABLE NS_IMETHOD MatchDate(PRTime aTime, PRBool *_retval NS_OUTPARAM) = 0;

  /* boolean matchStatus (in unsigned long aStatus); */
  NS_SCRIPTABLE NS_IMETHOD MatchStatus(PRUint32 aStatus, PRBool *_retval NS_OUTPARAM) = 0;

  /* boolean matchPriority (in nsMsgPriorityValue priority); */
  NS_SCRIPTABLE NS_IMETHOD MatchPriority(nsMsgPriorityValue priority, PRBool *_retval NS_OUTPARAM) = 0;

  /* boolean matchAge (in PRTime days); */
  NS_SCRIPTABLE NS_IMETHOD MatchAge(PRTime days, PRBool *_retval NS_OUTPARAM) = 0;

  /* boolean matchSize (in unsigned long size); */
  NS_SCRIPTABLE NS_IMETHOD MatchSize(PRUint32 size, PRBool *_retval NS_OUTPARAM) = 0;

  /* boolean matchLabel (in nsMsgLabelValue aLabelValue); */
  NS_SCRIPTABLE NS_IMETHOD MatchLabel(nsMsgLabelValue aLabelValue, PRBool *_retval NS_OUTPARAM) = 0;

  /* boolean matchJunkStatus (in string aJunkScore); */
  NS_SCRIPTABLE NS_IMETHOD MatchJunkStatus(const char *aJunkScore, PRBool *_retval NS_OUTPARAM) = 0;

  /* boolean matchJunkPercent (in unsigned long aJunkPercent); */
  NS_SCRIPTABLE NS_IMETHOD MatchJunkPercent(PRUint32 aJunkPercent, PRBool *_retval NS_OUTPARAM) = 0;

  /* boolean matchJunkScoreOrigin (in string aJunkScoreOrigin); */
  NS_SCRIPTABLE NS_IMETHOD MatchJunkScoreOrigin(const char *aJunkScoreOrigin, PRBool *_retval NS_OUTPARAM) = 0;

  /**
     * Test if the body of the passed in message matches "this" search term.
     * @param aScopeTerm scope of search
     * @param aOffset offset of message in message store.
     * @param aLength length of message.
     * @param aCharset folder charset.
     * @param aMsg db msg hdr of message to match.
     * @param aDB db containing msg header.
     */
  /* boolean matchBody (in nsIMsgSearchScopeTerm aScopeTerm, in unsigned long long aOffset, in unsigned long aLength, in string aCharset, in nsIMsgDBHdr aMsg, in nsIMsgDatabase aDb); */
  NS_SCRIPTABLE NS_IMETHOD MatchBody(nsIMsgSearchScopeTerm *aScopeTerm, PRUint64 aOffset, PRUint32 aLength, const char *aCharset, nsIMsgDBHdr *aMsg, nsIMsgDatabase *aDb, PRBool *_retval NS_OUTPARAM) = 0;

  /**
     * Test if the arbitrary header specified by this search term
     * matches the corresponding header in the passed in message.
     *
     * @param aScopeTerm scope of search
     * @param aOffset offset of message in message store
     * @param aLength length of message
     * @param aCharset The charset to apply to un-labeled non-UTF-8 data.
     * @param aCharsetOverride If true, aCharset is used instead of any
     *                         charset labeling other than UTF-8.
     *
     * N.B. This is noscript because headers is a null-separated list of
     * strings, which is not scriptable.
     */
  /* [noscript] boolean matchArbitraryHeader (in nsIMsgSearchScopeTerm aScopeTerm, in unsigned long long aOffset, in unsigned long aLength, in string aCharset, in boolean aCharsetOverride, in nsIMsgDBHdr aMsg, in nsIMsgDatabase aDb, in string aHeaders, in unsigned long aHeaderLength, in boolean aForFilters); */
  NS_IMETHOD MatchArbitraryHeader(nsIMsgSearchScopeTerm *aScopeTerm, PRUint64 aOffset, PRUint32 aLength, const char *aCharset, PRBool aCharsetOverride, nsIMsgDBHdr *aMsg, nsIMsgDatabase *aDb, const char *aHeaders, PRUint32 aHeaderLength, PRBool aForFilters, PRBool *_retval NS_OUTPARAM) = 0;

  /**
     * Compares value.str with nsIMsgHdr::GetProperty(hdrProperty).
     * @param msg   msg to match db hdr property of.
     *
     * @returns     true if msg matches property, false otherwise.
     */
  /* boolean matchHdrProperty (in nsIMsgDBHdr msg); */
  NS_SCRIPTABLE NS_IMETHOD MatchHdrProperty(nsIMsgDBHdr *msg, PRBool *_retval NS_OUTPARAM) = 0;

  /**
     * Compares value.status with nsIMsgHdr::GetUint32Property(hdrProperty).
     * @param msg   msg to match db hdr property of.
     *
     * @returns     true if msg matches property, false otherwise.
     */
  /* boolean matchUint32HdrProperty (in nsIMsgDBHdr msg); */
  NS_SCRIPTABLE NS_IMETHOD MatchUint32HdrProperty(nsIMsgDBHdr *msg, PRBool *_retval NS_OUTPARAM) = 0;

  /**
     * Compares value.status with the folder flags of the msg's folder.
     * @param msg   msgHdr whose folder's flag we want to compare.
     *
     * @returns     true if folder's flags match value.status, false otherwise.
     */
  /* boolean matchFolderFlag (in nsIMsgDBHdr msg); */
  NS_SCRIPTABLE NS_IMETHOD MatchFolderFlag(nsIMsgDBHdr *msg, PRBool *_retval NS_OUTPARAM) = 0;

  /* readonly attribute boolean matchAllBeforeDeciding; */
  NS_SCRIPTABLE NS_IMETHOD GetMatchAllBeforeDeciding(PRBool *aMatchAllBeforeDeciding) = 0;

  /* readonly attribute ACString termAsString; */
  NS_SCRIPTABLE NS_IMETHOD GetTermAsString(nsACString & aTermAsString) = 0;

  /* boolean matchKeyword (in ACString keyword); */
  NS_SCRIPTABLE NS_IMETHOD MatchKeyword(const nsACString & keyword, PRBool *_retval NS_OUTPARAM) = 0;

  /* attribute boolean matchAll; */
  NS_SCRIPTABLE NS_IMETHOD GetMatchAll(PRBool *aMatchAll) = 0;
  NS_SCRIPTABLE NS_IMETHOD SetMatchAll(PRBool aMatchAll) = 0;

  /**
     * Does the message match the custom search term?
     *
     * @param  msg  message database object representing the message
     *
     * @return      true if message matches
     */
  /* boolean matchCustom (in nsIMsgDBHdr msg); */
  NS_SCRIPTABLE NS_IMETHOD MatchCustom(nsIMsgDBHdr *msg, PRBool *_retval NS_OUTPARAM) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsIMsgSearchTerm, NS_IMSGSEARCHTERM_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIMSGSEARCHTERM \
  NS_SCRIPTABLE NS_IMETHOD GetAttrib(nsMsgSearchAttribValue *aAttrib); \
  NS_SCRIPTABLE NS_IMETHOD SetAttrib(nsMsgSearchAttribValue aAttrib); \
  NS_SCRIPTABLE NS_IMETHOD GetOp(nsMsgSearchOpValue *aOp); \
  NS_SCRIPTABLE NS_IMETHOD SetOp(nsMsgSearchOpValue aOp); \
  NS_SCRIPTABLE NS_IMETHOD GetValue(nsIMsgSearchValue **aValue); \
  NS_SCRIPTABLE NS_IMETHOD SetValue(nsIMsgSearchValue *aValue); \
  NS_SCRIPTABLE NS_IMETHOD GetBooleanAnd(PRBool *aBooleanAnd); \
  NS_SCRIPTABLE NS_IMETHOD SetBooleanAnd(PRBool aBooleanAnd); \
  NS_SCRIPTABLE NS_IMETHOD GetArbitraryHeader(nsACString & aArbitraryHeader); \
  NS_SCRIPTABLE NS_IMETHOD SetArbitraryHeader(const nsACString & aArbitraryHeader); \
  NS_SCRIPTABLE NS_IMETHOD GetHdrProperty(nsACString & aHdrProperty); \
  NS_SCRIPTABLE NS_IMETHOD SetHdrProperty(const nsACString & aHdrProperty); \
  NS_SCRIPTABLE NS_IMETHOD GetCustomId(nsACString & aCustomId); \
  NS_SCRIPTABLE NS_IMETHOD SetCustomId(const nsACString & aCustomId); \
  NS_SCRIPTABLE NS_IMETHOD GetBeginsGrouping(PRBool *aBeginsGrouping); \
  NS_SCRIPTABLE NS_IMETHOD SetBeginsGrouping(PRBool aBeginsGrouping); \
  NS_SCRIPTABLE NS_IMETHOD GetEndsGrouping(PRBool *aEndsGrouping); \
  NS_SCRIPTABLE NS_IMETHOD SetEndsGrouping(PRBool aEndsGrouping); \
  NS_SCRIPTABLE NS_IMETHOD MatchRfc822String(const char *aString, const char *charset, PRBool charsetOverride, PRBool *_retval NS_OUTPARAM); \
  NS_SCRIPTABLE NS_IMETHOD MatchRfc2047String(const char *aString, const char *charset, PRBool charsetOverride, PRBool *_retval NS_OUTPARAM); \
  NS_SCRIPTABLE NS_IMETHOD MatchDate(PRTime aTime, PRBool *_retval NS_OUTPARAM); \
  NS_SCRIPTABLE NS_IMETHOD MatchStatus(PRUint32 aStatus, PRBool *_retval NS_OUTPARAM); \
  NS_SCRIPTABLE NS_IMETHOD MatchPriority(nsMsgPriorityValue priority, PRBool *_retval NS_OUTPARAM); \
  NS_SCRIPTABLE NS_IMETHOD MatchAge(PRTime days, PRBool *_retval NS_OUTPARAM); \
  NS_SCRIPTABLE NS_IMETHOD MatchSize(PRUint32 size, PRBool *_retval NS_OUTPARAM); \
  NS_SCRIPTABLE NS_IMETHOD MatchLabel(nsMsgLabelValue aLabelValue, PRBool *_retval NS_OUTPARAM); \
  NS_SCRIPTABLE NS_IMETHOD MatchJunkStatus(const char *aJunkScore, PRBool *_retval NS_OUTPARAM); \
  NS_SCRIPTABLE NS_IMETHOD MatchJunkPercent(PRUint32 aJunkPercent, PRBool *_retval NS_OUTPARAM); \
  NS_SCRIPTABLE NS_IMETHOD MatchJunkScoreOrigin(const char *aJunkScoreOrigin, PRBool *_retval NS_OUTPARAM); \
  NS_SCRIPTABLE NS_IMETHOD MatchBody(nsIMsgSearchScopeTerm *aScopeTerm, PRUint64 aOffset, PRUint32 aLength, const char *aCharset, nsIMsgDBHdr *aMsg, nsIMsgDatabase *aDb, PRBool *_retval NS_OUTPARAM); \
  NS_IMETHOD MatchArbitraryHeader(nsIMsgSearchScopeTerm *aScopeTerm, PRUint64 aOffset, PRUint32 aLength, const char *aCharset, PRBool aCharsetOverride, nsIMsgDBHdr *aMsg, nsIMsgDatabase *aDb, const char *aHeaders, PRUint32 aHeaderLength, PRBool aForFilters, PRBool *_retval NS_OUTPARAM); \
  NS_SCRIPTABLE NS_IMETHOD MatchHdrProperty(nsIMsgDBHdr *msg, PRBool *_retval NS_OUTPARAM); \
  NS_SCRIPTABLE NS_IMETHOD MatchUint32HdrProperty(nsIMsgDBHdr *msg, PRBool *_retval NS_OUTPARAM); \
  NS_SCRIPTABLE NS_IMETHOD MatchFolderFlag(nsIMsgDBHdr *msg, PRBool *_retval NS_OUTPARAM); \
  NS_SCRIPTABLE NS_IMETHOD GetMatchAllBeforeDeciding(PRBool *aMatchAllBeforeDeciding); \
  NS_SCRIPTABLE NS_IMETHOD GetTermAsString(nsACString & aTermAsString); \
  NS_SCRIPTABLE NS_IMETHOD MatchKeyword(const nsACString & keyword, PRBool *_retval NS_OUTPARAM); \
  NS_SCRIPTABLE NS_IMETHOD GetMatchAll(PRBool *aMatchAll); \
  NS_SCRIPTABLE NS_IMETHOD SetMatchAll(PRBool aMatchAll); \
  NS_SCRIPTABLE NS_IMETHOD MatchCustom(nsIMsgDBHdr *msg, PRBool *_retval NS_OUTPARAM); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIMSGSEARCHTERM(_to) \
  NS_SCRIPTABLE NS_IMETHOD GetAttrib(nsMsgSearchAttribValue *aAttrib) { return _to GetAttrib(aAttrib); } \
  NS_SCRIPTABLE NS_IMETHOD SetAttrib(nsMsgSearchAttribValue aAttrib) { return _to SetAttrib(aAttrib); } \
  NS_SCRIPTABLE NS_IMETHOD GetOp(nsMsgSearchOpValue *aOp) { return _to GetOp(aOp); } \
  NS_SCRIPTABLE NS_IMETHOD SetOp(nsMsgSearchOpValue aOp) { return _to SetOp(aOp); } \
  NS_SCRIPTABLE NS_IMETHOD GetValue(nsIMsgSearchValue **aValue) { return _to GetValue(aValue); } \
  NS_SCRIPTABLE NS_IMETHOD SetValue(nsIMsgSearchValue *aValue) { return _to SetValue(aValue); } \
  NS_SCRIPTABLE NS_IMETHOD GetBooleanAnd(PRBool *aBooleanAnd) { return _to GetBooleanAnd(aBooleanAnd); } \
  NS_SCRIPTABLE NS_IMETHOD SetBooleanAnd(PRBool aBooleanAnd) { return _to SetBooleanAnd(aBooleanAnd); } \
  NS_SCRIPTABLE NS_IMETHOD GetArbitraryHeader(nsACString & aArbitraryHeader) { return _to GetArbitraryHeader(aArbitraryHeader); } \
  NS_SCRIPTABLE NS_IMETHOD SetArbitraryHeader(const nsACString & aArbitraryHeader) { return _to SetArbitraryHeader(aArbitraryHeader); } \
  NS_SCRIPTABLE NS_IMETHOD GetHdrProperty(nsACString & aHdrProperty) { return _to GetHdrProperty(aHdrProperty); } \
  NS_SCRIPTABLE NS_IMETHOD SetHdrProperty(const nsACString & aHdrProperty) { return _to SetHdrProperty(aHdrProperty); } \
  NS_SCRIPTABLE NS_IMETHOD GetCustomId(nsACString & aCustomId) { return _to GetCustomId(aCustomId); } \
  NS_SCRIPTABLE NS_IMETHOD SetCustomId(const nsACString & aCustomId) { return _to SetCustomId(aCustomId); } \
  NS_SCRIPTABLE NS_IMETHOD GetBeginsGrouping(PRBool *aBeginsGrouping) { return _to GetBeginsGrouping(aBeginsGrouping); } \
  NS_SCRIPTABLE NS_IMETHOD SetBeginsGrouping(PRBool aBeginsGrouping) { return _to SetBeginsGrouping(aBeginsGrouping); } \
  NS_SCRIPTABLE NS_IMETHOD GetEndsGrouping(PRBool *aEndsGrouping) { return _to GetEndsGrouping(aEndsGrouping); } \
  NS_SCRIPTABLE NS_IMETHOD SetEndsGrouping(PRBool aEndsGrouping) { return _to SetEndsGrouping(aEndsGrouping); } \
  NS_SCRIPTABLE NS_IMETHOD MatchRfc822String(const char *aString, const char *charset, PRBool charsetOverride, PRBool *_retval NS_OUTPARAM) { return _to MatchRfc822String(aString, charset, charsetOverride, _retval); } \
  NS_SCRIPTABLE NS_IMETHOD MatchRfc2047String(const char *aString, const char *charset, PRBool charsetOverride, PRBool *_retval NS_OUTPARAM) { return _to MatchRfc2047String(aString, charset, charsetOverride, _retval); } \
  NS_SCRIPTABLE NS_IMETHOD MatchDate(PRTime aTime, PRBool *_retval NS_OUTPARAM) { return _to MatchDate(aTime, _retval); } \
  NS_SCRIPTABLE NS_IMETHOD MatchStatus(PRUint32 aStatus, PRBool *_retval NS_OUTPARAM) { return _to MatchStatus(aStatus, _retval); } \
  NS_SCRIPTABLE NS_IMETHOD MatchPriority(nsMsgPriorityValue priority, PRBool *_retval NS_OUTPARAM) { return _to MatchPriority(priority, _retval); } \
  NS_SCRIPTABLE NS_IMETHOD MatchAge(PRTime days, PRBool *_retval NS_OUTPARAM) { return _to MatchAge(days, _retval); } \
  NS_SCRIPTABLE NS_IMETHOD MatchSize(PRUint32 size, PRBool *_retval NS_OUTPARAM) { return _to MatchSize(size, _retval); } \
  NS_SCRIPTABLE NS_IMETHOD MatchLabel(nsMsgLabelValue aLabelValue, PRBool *_retval NS_OUTPARAM) { return _to MatchLabel(aLabelValue, _retval); } \
  NS_SCRIPTABLE NS_IMETHOD MatchJunkStatus(const char *aJunkScore, PRBool *_retval NS_OUTPARAM) { return _to MatchJunkStatus(aJunkScore, _retval); } \
  NS_SCRIPTABLE NS_IMETHOD MatchJunkPercent(PRUint32 aJunkPercent, PRBool *_retval NS_OUTPARAM) { return _to MatchJunkPercent(aJunkPercent, _retval); } \
  NS_SCRIPTABLE NS_IMETHOD MatchJunkScoreOrigin(const char *aJunkScoreOrigin, PRBool *_retval NS_OUTPARAM) { return _to MatchJunkScoreOrigin(aJunkScoreOrigin, _retval); } \
  NS_SCRIPTABLE NS_IMETHOD MatchBody(nsIMsgSearchScopeTerm *aScopeTerm, PRUint64 aOffset, PRUint32 aLength, const char *aCharset, nsIMsgDBHdr *aMsg, nsIMsgDatabase *aDb, PRBool *_retval NS_OUTPARAM) { return _to MatchBody(aScopeTerm, aOffset, aLength, aCharset, aMsg, aDb, _retval); } \
  NS_IMETHOD MatchArbitraryHeader(nsIMsgSearchScopeTerm *aScopeTerm, PRUint64 aOffset, PRUint32 aLength, const char *aCharset, PRBool aCharsetOverride, nsIMsgDBHdr *aMsg, nsIMsgDatabase *aDb, const char *aHeaders, PRUint32 aHeaderLength, PRBool aForFilters, PRBool *_retval NS_OUTPARAM) { return _to MatchArbitraryHeader(aScopeTerm, aOffset, aLength, aCharset, aCharsetOverride, aMsg, aDb, aHeaders, aHeaderLength, aForFilters, _retval); } \
  NS_SCRIPTABLE NS_IMETHOD MatchHdrProperty(nsIMsgDBHdr *msg, PRBool *_retval NS_OUTPARAM) { return _to MatchHdrProperty(msg, _retval); } \
  NS_SCRIPTABLE NS_IMETHOD MatchUint32HdrProperty(nsIMsgDBHdr *msg, PRBool *_retval NS_OUTPARAM) { return _to MatchUint32HdrProperty(msg, _retval); } \
  NS_SCRIPTABLE NS_IMETHOD MatchFolderFlag(nsIMsgDBHdr *msg, PRBool *_retval NS_OUTPARAM) { return _to MatchFolderFlag(msg, _retval); } \
  NS_SCRIPTABLE NS_IMETHOD GetMatchAllBeforeDeciding(PRBool *aMatchAllBeforeDeciding) { return _to GetMatchAllBeforeDeciding(aMatchAllBeforeDeciding); } \
  NS_SCRIPTABLE NS_IMETHOD GetTermAsString(nsACString & aTermAsString) { return _to GetTermAsString(aTermAsString); } \
  NS_SCRIPTABLE NS_IMETHOD MatchKeyword(const nsACString & keyword, PRBool *_retval NS_OUTPARAM) { return _to MatchKeyword(keyword, _retval); } \
  NS_SCRIPTABLE NS_IMETHOD GetMatchAll(PRBool *aMatchAll) { return _to GetMatchAll(aMatchAll); } \
  NS_SCRIPTABLE NS_IMETHOD SetMatchAll(PRBool aMatchAll) { return _to SetMatchAll(aMatchAll); } \
  NS_SCRIPTABLE NS_IMETHOD MatchCustom(nsIMsgDBHdr *msg, PRBool *_retval NS_OUTPARAM) { return _to MatchCustom(msg, _retval); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIMSGSEARCHTERM(_to) \
  NS_SCRIPTABLE NS_IMETHOD GetAttrib(nsMsgSearchAttribValue *aAttrib) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetAttrib(aAttrib); } \
  NS_SCRIPTABLE NS_IMETHOD SetAttrib(nsMsgSearchAttribValue aAttrib) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetAttrib(aAttrib); } \
  NS_SCRIPTABLE NS_IMETHOD GetOp(nsMsgSearchOpValue *aOp) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetOp(aOp); } \
  NS_SCRIPTABLE NS_IMETHOD SetOp(nsMsgSearchOpValue aOp) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetOp(aOp); } \
  NS_SCRIPTABLE NS_IMETHOD GetValue(nsIMsgSearchValue **aValue) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetValue(aValue); } \
  NS_SCRIPTABLE NS_IMETHOD SetValue(nsIMsgSearchValue *aValue) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetValue(aValue); } \
  NS_SCRIPTABLE NS_IMETHOD GetBooleanAnd(PRBool *aBooleanAnd) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetBooleanAnd(aBooleanAnd); } \
  NS_SCRIPTABLE NS_IMETHOD SetBooleanAnd(PRBool aBooleanAnd) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetBooleanAnd(aBooleanAnd); } \
  NS_SCRIPTABLE NS_IMETHOD GetArbitraryHeader(nsACString & aArbitraryHeader) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetArbitraryHeader(aArbitraryHeader); } \
  NS_SCRIPTABLE NS_IMETHOD SetArbitraryHeader(const nsACString & aArbitraryHeader) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetArbitraryHeader(aArbitraryHeader); } \
  NS_SCRIPTABLE NS_IMETHOD GetHdrProperty(nsACString & aHdrProperty) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetHdrProperty(aHdrProperty); } \
  NS_SCRIPTABLE NS_IMETHOD SetHdrProperty(const nsACString & aHdrProperty) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetHdrProperty(aHdrProperty); } \
  NS_SCRIPTABLE NS_IMETHOD GetCustomId(nsACString & aCustomId) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetCustomId(aCustomId); } \
  NS_SCRIPTABLE NS_IMETHOD SetCustomId(const nsACString & aCustomId) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetCustomId(aCustomId); } \
  NS_SCRIPTABLE NS_IMETHOD GetBeginsGrouping(PRBool *aBeginsGrouping) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetBeginsGrouping(aBeginsGrouping); } \
  NS_SCRIPTABLE NS_IMETHOD SetBeginsGrouping(PRBool aBeginsGrouping) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetBeginsGrouping(aBeginsGrouping); } \
  NS_SCRIPTABLE NS_IMETHOD GetEndsGrouping(PRBool *aEndsGrouping) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetEndsGrouping(aEndsGrouping); } \
  NS_SCRIPTABLE NS_IMETHOD SetEndsGrouping(PRBool aEndsGrouping) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetEndsGrouping(aEndsGrouping); } \
  NS_SCRIPTABLE NS_IMETHOD MatchRfc822String(const char *aString, const char *charset, PRBool charsetOverride, PRBool *_retval NS_OUTPARAM) { return !_to ? NS_ERROR_NULL_POINTER : _to->MatchRfc822String(aString, charset, charsetOverride, _retval); } \
  NS_SCRIPTABLE NS_IMETHOD MatchRfc2047String(const char *aString, const char *charset, PRBool charsetOverride, PRBool *_retval NS_OUTPARAM) { return !_to ? NS_ERROR_NULL_POINTER : _to->MatchRfc2047String(aString, charset, charsetOverride, _retval); } \
  NS_SCRIPTABLE NS_IMETHOD MatchDate(PRTime aTime, PRBool *_retval NS_OUTPARAM) { return !_to ? NS_ERROR_NULL_POINTER : _to->MatchDate(aTime, _retval); } \
  NS_SCRIPTABLE NS_IMETHOD MatchStatus(PRUint32 aStatus, PRBool *_retval NS_OUTPARAM) { return !_to ? NS_ERROR_NULL_POINTER : _to->MatchStatus(aStatus, _retval); } \
  NS_SCRIPTABLE NS_IMETHOD MatchPriority(nsMsgPriorityValue priority, PRBool *_retval NS_OUTPARAM) { return !_to ? NS_ERROR_NULL_POINTER : _to->MatchPriority(priority, _retval); } \
  NS_SCRIPTABLE NS_IMETHOD MatchAge(PRTime days, PRBool *_retval NS_OUTPARAM) { return !_to ? NS_ERROR_NULL_POINTER : _to->MatchAge(days, _retval); } \
  NS_SCRIPTABLE NS_IMETHOD MatchSize(PRUint32 size, PRBool *_retval NS_OUTPARAM) { return !_to ? NS_ERROR_NULL_POINTER : _to->MatchSize(size, _retval); } \
  NS_SCRIPTABLE NS_IMETHOD MatchLabel(nsMsgLabelValue aLabelValue, PRBool *_retval NS_OUTPARAM) { return !_to ? NS_ERROR_NULL_POINTER : _to->MatchLabel(aLabelValue, _retval); } \
  NS_SCRIPTABLE NS_IMETHOD MatchJunkStatus(const char *aJunkScore, PRBool *_retval NS_OUTPARAM) { return !_to ? NS_ERROR_NULL_POINTER : _to->MatchJunkStatus(aJunkScore, _retval); } \
  NS_SCRIPTABLE NS_IMETHOD MatchJunkPercent(PRUint32 aJunkPercent, PRBool *_retval NS_OUTPARAM) { return !_to ? NS_ERROR_NULL_POINTER : _to->MatchJunkPercent(aJunkPercent, _retval); } \
  NS_SCRIPTABLE NS_IMETHOD MatchJunkScoreOrigin(const char *aJunkScoreOrigin, PRBool *_retval NS_OUTPARAM) { return !_to ? NS_ERROR_NULL_POINTER : _to->MatchJunkScoreOrigin(aJunkScoreOrigin, _retval); } \
  NS_SCRIPTABLE NS_IMETHOD MatchBody(nsIMsgSearchScopeTerm *aScopeTerm, PRUint64 aOffset, PRUint32 aLength, const char *aCharset, nsIMsgDBHdr *aMsg, nsIMsgDatabase *aDb, PRBool *_retval NS_OUTPARAM) { return !_to ? NS_ERROR_NULL_POINTER : _to->MatchBody(aScopeTerm, aOffset, aLength, aCharset, aMsg, aDb, _retval); } \
  NS_IMETHOD MatchArbitraryHeader(nsIMsgSearchScopeTerm *aScopeTerm, PRUint64 aOffset, PRUint32 aLength, const char *aCharset, PRBool aCharsetOverride, nsIMsgDBHdr *aMsg, nsIMsgDatabase *aDb, const char *aHeaders, PRUint32 aHeaderLength, PRBool aForFilters, PRBool *_retval NS_OUTPARAM) { return !_to ? NS_ERROR_NULL_POINTER : _to->MatchArbitraryHeader(aScopeTerm, aOffset, aLength, aCharset, aCharsetOverride, aMsg, aDb, aHeaders, aHeaderLength, aForFilters, _retval); } \
  NS_SCRIPTABLE NS_IMETHOD MatchHdrProperty(nsIMsgDBHdr *msg, PRBool *_retval NS_OUTPARAM) { return !_to ? NS_ERROR_NULL_POINTER : _to->MatchHdrProperty(msg, _retval); } \
  NS_SCRIPTABLE NS_IMETHOD MatchUint32HdrProperty(nsIMsgDBHdr *msg, PRBool *_retval NS_OUTPARAM) { return !_to ? NS_ERROR_NULL_POINTER : _to->MatchUint32HdrProperty(msg, _retval); } \
  NS_SCRIPTABLE NS_IMETHOD MatchFolderFlag(nsIMsgDBHdr *msg, PRBool *_retval NS_OUTPARAM) { return !_to ? NS_ERROR_NULL_POINTER : _to->MatchFolderFlag(msg, _retval); } \
  NS_SCRIPTABLE NS_IMETHOD GetMatchAllBeforeDeciding(PRBool *aMatchAllBeforeDeciding) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetMatchAllBeforeDeciding(aMatchAllBeforeDeciding); } \
  NS_SCRIPTABLE NS_IMETHOD GetTermAsString(nsACString & aTermAsString) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetTermAsString(aTermAsString); } \
  NS_SCRIPTABLE NS_IMETHOD MatchKeyword(const nsACString & keyword, PRBool *_retval NS_OUTPARAM) { return !_to ? NS_ERROR_NULL_POINTER : _to->MatchKeyword(keyword, _retval); } \
  NS_SCRIPTABLE NS_IMETHOD GetMatchAll(PRBool *aMatchAll) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetMatchAll(aMatchAll); } \
  NS_SCRIPTABLE NS_IMETHOD SetMatchAll(PRBool aMatchAll) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetMatchAll(aMatchAll); } \
  NS_SCRIPTABLE NS_IMETHOD MatchCustom(nsIMsgDBHdr *msg, PRBool *_retval NS_OUTPARAM) { return !_to ? NS_ERROR_NULL_POINTER : _to->MatchCustom(msg, _retval); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsMsgSearchTerm : public nsIMsgSearchTerm
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIMSGSEARCHTERM

  nsMsgSearchTerm();

private:
  ~nsMsgSearchTerm();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsMsgSearchTerm, nsIMsgSearchTerm)

nsMsgSearchTerm::nsMsgSearchTerm()
{
  /* member initializers and constructor code */
}

nsMsgSearchTerm::~nsMsgSearchTerm()
{
  /* destructor code */
}

/* attribute nsMsgSearchAttribValue attrib; */
NS_IMETHODIMP nsMsgSearchTerm::GetAttrib(nsMsgSearchAttribValue *aAttrib)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMsgSearchTerm::SetAttrib(nsMsgSearchAttribValue aAttrib)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute nsMsgSearchOpValue op; */
NS_IMETHODIMP nsMsgSearchTerm::GetOp(nsMsgSearchOpValue *aOp)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMsgSearchTerm::SetOp(nsMsgSearchOpValue aOp)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute nsIMsgSearchValue value; */
NS_IMETHODIMP nsMsgSearchTerm::GetValue(nsIMsgSearchValue **aValue)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMsgSearchTerm::SetValue(nsIMsgSearchValue *aValue)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute boolean booleanAnd; */
NS_IMETHODIMP nsMsgSearchTerm::GetBooleanAnd(PRBool *aBooleanAnd)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMsgSearchTerm::SetBooleanAnd(PRBool aBooleanAnd)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute ACString arbitraryHeader; */
NS_IMETHODIMP nsMsgSearchTerm::GetArbitraryHeader(nsACString & aArbitraryHeader)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMsgSearchTerm::SetArbitraryHeader(const nsACString & aArbitraryHeader)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute ACString hdrProperty; */
NS_IMETHODIMP nsMsgSearchTerm::GetHdrProperty(nsACString & aHdrProperty)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMsgSearchTerm::SetHdrProperty(const nsACString & aHdrProperty)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute ACString customId; */
NS_IMETHODIMP nsMsgSearchTerm::GetCustomId(nsACString & aCustomId)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMsgSearchTerm::SetCustomId(const nsACString & aCustomId)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute boolean beginsGrouping; */
NS_IMETHODIMP nsMsgSearchTerm::GetBeginsGrouping(PRBool *aBeginsGrouping)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMsgSearchTerm::SetBeginsGrouping(PRBool aBeginsGrouping)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute boolean endsGrouping; */
NS_IMETHODIMP nsMsgSearchTerm::GetEndsGrouping(PRBool *aEndsGrouping)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMsgSearchTerm::SetEndsGrouping(PRBool aEndsGrouping)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* boolean matchRfc822String (in string aString, in string charset, in boolean charsetOverride); */
NS_IMETHODIMP nsMsgSearchTerm::MatchRfc822String(const char *aString, const char *charset, PRBool charsetOverride, PRBool *_retval NS_OUTPARAM)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* boolean matchRfc2047String (in string aString, in string charset, in boolean charsetOverride); */
NS_IMETHODIMP nsMsgSearchTerm::MatchRfc2047String(const char *aString, const char *charset, PRBool charsetOverride, PRBool *_retval NS_OUTPARAM)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* boolean matchDate (in PRTime aTime); */
NS_IMETHODIMP nsMsgSearchTerm::MatchDate(PRTime aTime, PRBool *_retval NS_OUTPARAM)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* boolean matchStatus (in unsigned long aStatus); */
NS_IMETHODIMP nsMsgSearchTerm::MatchStatus(PRUint32 aStatus, PRBool *_retval NS_OUTPARAM)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* boolean matchPriority (in nsMsgPriorityValue priority); */
NS_IMETHODIMP nsMsgSearchTerm::MatchPriority(nsMsgPriorityValue priority, PRBool *_retval NS_OUTPARAM)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* boolean matchAge (in PRTime days); */
NS_IMETHODIMP nsMsgSearchTerm::MatchAge(PRTime days, PRBool *_retval NS_OUTPARAM)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* boolean matchSize (in unsigned long size); */
NS_IMETHODIMP nsMsgSearchTerm::MatchSize(PRUint32 size, PRBool *_retval NS_OUTPARAM)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* boolean matchLabel (in nsMsgLabelValue aLabelValue); */
NS_IMETHODIMP nsMsgSearchTerm::MatchLabel(nsMsgLabelValue aLabelValue, PRBool *_retval NS_OUTPARAM)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* boolean matchJunkStatus (in string aJunkScore); */
NS_IMETHODIMP nsMsgSearchTerm::MatchJunkStatus(const char *aJunkScore, PRBool *_retval NS_OUTPARAM)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* boolean matchJunkPercent (in unsigned long aJunkPercent); */
NS_IMETHODIMP nsMsgSearchTerm::MatchJunkPercent(PRUint32 aJunkPercent, PRBool *_retval NS_OUTPARAM)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* boolean matchJunkScoreOrigin (in string aJunkScoreOrigin); */
NS_IMETHODIMP nsMsgSearchTerm::MatchJunkScoreOrigin(const char *aJunkScoreOrigin, PRBool *_retval NS_OUTPARAM)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* boolean matchBody (in nsIMsgSearchScopeTerm aScopeTerm, in unsigned long long aOffset, in unsigned long aLength, in string aCharset, in nsIMsgDBHdr aMsg, in nsIMsgDatabase aDb); */
NS_IMETHODIMP nsMsgSearchTerm::MatchBody(nsIMsgSearchScopeTerm *aScopeTerm, PRUint64 aOffset, PRUint32 aLength, const char *aCharset, nsIMsgDBHdr *aMsg, nsIMsgDatabase *aDb, PRBool *_retval NS_OUTPARAM)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* [noscript] boolean matchArbitraryHeader (in nsIMsgSearchScopeTerm aScopeTerm, in unsigned long long aOffset, in unsigned long aLength, in string aCharset, in boolean aCharsetOverride, in nsIMsgDBHdr aMsg, in nsIMsgDatabase aDb, in string aHeaders, in unsigned long aHeaderLength, in boolean aForFilters); */
NS_IMETHODIMP nsMsgSearchTerm::MatchArbitraryHeader(nsIMsgSearchScopeTerm *aScopeTerm, PRUint64 aOffset, PRUint32 aLength, const char *aCharset, PRBool aCharsetOverride, nsIMsgDBHdr *aMsg, nsIMsgDatabase *aDb, const char *aHeaders, PRUint32 aHeaderLength, PRBool aForFilters, PRBool *_retval NS_OUTPARAM)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* boolean matchHdrProperty (in nsIMsgDBHdr msg); */
NS_IMETHODIMP nsMsgSearchTerm::MatchHdrProperty(nsIMsgDBHdr *msg, PRBool *_retval NS_OUTPARAM)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* boolean matchUint32HdrProperty (in nsIMsgDBHdr msg); */
NS_IMETHODIMP nsMsgSearchTerm::MatchUint32HdrProperty(nsIMsgDBHdr *msg, PRBool *_retval NS_OUTPARAM)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* boolean matchFolderFlag (in nsIMsgDBHdr msg); */
NS_IMETHODIMP nsMsgSearchTerm::MatchFolderFlag(nsIMsgDBHdr *msg, PRBool *_retval NS_OUTPARAM)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute boolean matchAllBeforeDeciding; */
NS_IMETHODIMP nsMsgSearchTerm::GetMatchAllBeforeDeciding(PRBool *aMatchAllBeforeDeciding)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute ACString termAsString; */
NS_IMETHODIMP nsMsgSearchTerm::GetTermAsString(nsACString & aTermAsString)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* boolean matchKeyword (in ACString keyword); */
NS_IMETHODIMP nsMsgSearchTerm::MatchKeyword(const nsACString & keyword, PRBool *_retval NS_OUTPARAM)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute boolean matchAll; */
NS_IMETHODIMP nsMsgSearchTerm::GetMatchAll(PRBool *aMatchAll)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMsgSearchTerm::SetMatchAll(PRBool aMatchAll)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* boolean matchCustom (in nsIMsgDBHdr msg); */
NS_IMETHODIMP nsMsgSearchTerm::MatchCustom(nsIMsgDBHdr *msg, PRBool *_retval NS_OUTPARAM)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIMsgSearchTerm_h__ */
